---
meta:
  id: uvsqsat
  endian: be
doc: |
  : UVSQsat telemetry description file 
  : Version 0.2.8
  :
  : reference documentation 
  :      UVSQsat-Beacon description for web site 
  :  
  : This ksy file is used for different automatic code generation 
  :    - ksy file to programming language thanks o ksy compiler 
       - ksy file to graphwiz document thnaks to ksy compiler 
       - Ksy file to java textual display files thanks to JOSAST GeneratePOJOfromKSY tool (experimental)
       - Ksy file to FXML files and associated java files file thanks to JOSAST GeneratePOJOfromKSY tool (experimental)
       
  : Writing rules should be respected (see JOSAST project)
  :   - for interpreted value, variable should finish with 
  :      _raw if no interpretation is done 
  :      _c, _ma _v _dbm _mw according to the interpreted value 
  :   - the name of the interpreted value should be close to the displaed name (to limit rework)
  :      _c, _ma _v _dbm _mw are automaticaly converted to (C) (mA) (dbm) (mW)
  :
  :field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
  :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
  :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
  :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
  :field ctl: ax25_frame.ax25_header.ctl
  :field pid: ax25_frame.payload.pid
  
  

seq:
  - id: ax25_frame
    type: ax25_frame
    doc-ref: 'https://www.tapr.org/pub_ax25.html'

types:
  ax25_frame:
    seq:
      - id: ax25_header
        type: ax25_header
      - id: payload
        type:
          switch-on: ax25_header.ctl & 0x13
          cases:
            0x03: ui_frame
            0x13: ui_frame
            0x00: i_frame
            0x02: i_frame
            0x10: i_frame
            0x12: i_frame
            _: i_frame
            # 0x11: s_frame

  ax25_header:
    seq:
      - id: dest_callsign_raw
        type: callsign_raw
      - id: dest_ssid_raw
        type: ssid_mask
      - id: src_callsign_raw
        type: callsign_raw
      - id: src_ssid_raw
        type: ssid_mask
      - id: ctl
        type: u1

  callsign_raw:
    seq:
      - id: callsign_ror
        process: ror(1)
        size: 6
        type: callsign

  callsign:
    seq:
      - id: callsign
        type: str
        encoding: ASCII
        size: 6

  ssid_mask:
    seq:
      - id: ssid_mask
        type: u1
    instances:
      ssid:
        value: (ssid_mask & 0x0f) >> 1

  i_frame:
    seq:
      - id: pid
        type: u1
      - id: ax25_info
        size-eos: true

  ui_frame:
    seq:
      - id: pid
        type: u1
      - id: packet_primary_header
        type: packet_primary_header
      - id: packet_secondary_header
        type: packet_secondary_header
      - id: tlm
        type:
          switch-on: packet_secondary_header.sid
          cases:
            0x0E: amsat_ascii
            0x0F: beacon
            0x10: ants_hk
            0x11: obc_status
            0x12: obc_hk
            0x13: mainboard_all_science
            0x14: mainboard_hk
            0x15: ieps_hk_status
            0x16: trxvurx_hk
            0x17: imtq_hk 
            0x18: trxvutx_hk
            _: msg_or_unknow
            
      - id: ax25_info
        size-eos: true
# for command status and other message not recognised  
  msg_or_unknow:
    seq:
      - id: data
        size-eos: true
    instances:
     data_byte:
      value: data
        
# CCDS - primary packet header 
  packet_primary_header:
    seq:
      - id: packet_version_number
        type: b3
      - id: packet_id_packet_type
        type: b1
      - id: packet_id_secondary_header_flag
        type: b1
      - id: packet_id_application_process_id
        type: b11 
      - id: packet_sequence_control_secquence_flag
        type: b2
      - id: packet_sequence_control_count_or_name
        type: b14
      - id: packet_data_length
        type: u2
        
# CCDS - secondary  packet header 
  packet_secondary_header:
    seq:
      - id:  tm_packet_pus_version_number
        type: b4
      - id: spacecraft_time_reference_status
        type: b4
      - id: service_type_id
        type: u1
      - id: message_subtype_id
        type: u1
      - id: message_type_counter
        type: u2
      - id: destination_id
        type: u2
      - id: time
        type: u4
      - id: dummy1 # to verify 
        type: u2
      - id: dummy2 # to verify 
        type: u1
      - id: sid # used to identify the frame type
        type: u1
################################################################################
#
#   Ants Hk
#
################################################################################
  ants_hk:
    seq:
      - id: side_a_ants_temperature
        type: u2
      - id: side_a_ants_deployment_status
        type: u2
      - id: side_a_ants_uptime
        type: u4
      - id: side_a_deployment_count_antenna_1
        type: u1
      - id: side_a_deployment_count_antenna_2
        type: u1
      - id: side_a_deployment_count_antenna_3
        type: u1
      - id: side_a_deployment_count_antenna_4
        type: u1
      - id: side_a_deployment_time_antenna_1
        type: u2
      - id: side_a_deployment_time_antenna_2
        type: u2
      - id: side_a_deployment_time_antenna_3
        type: u2
      - id: side_a_deployment_time_antenna_4
        type: u2
      - id: side_b_ants_temperature
        type: u2
      - id: side_b_ants_deployment_status
        type: u2
      - id: side_b_ants_uptime
        type: u2
      - id: side_b_deployment_count_antenna_1
        type: u1
      - id: side_b_deployment_count_antenna_2
        type: u1
      - id: side_b_deployment_count_antenna_3
        type: u1
      - id: side_b_deployment_count_antenna_4
        type: u1
      - id: side_b_deployment_time_antenna_1
        type: u2
      - id: side_b_deployment_time_antenna_2
        type: u2
      - id: side_b_deployment_time_antenna_3
        type: u2
      - id: side_b_deployment_time_antenna_4
        type: u2
    instances:
     side_a_ants_temperature_raw:
      value:  side_a_ants_temperature
     side_a_ants_deployment_status_raw:
      value: side_a_ants_deployment_status
     side_a_ants_uptime_raw:
      value: side_a_ants_uptime
     side_a_deployment_count_antenna_1_raw:
      value: side_a_deployment_count_antenna_1
     side_a_deployment_count_antenna_2_raw:
      value: side_a_deployment_count_antenna_2
     side_a_deployment_count_antenna_3_raw:
      value: side_a_deployment_count_antenna_3
     side_a_deployment_count_antenna_4_raw:
      value: side_a_deployment_count_antenna_4
     side_a_deployment_time_antenna_1_raw:
      value: side_a_deployment_time_antenna_1
     side_a_deployment_time_antenna_2_raw:
      value: side_a_deployment_time_antenna_2
     side_a_deployment_time_antenna_3_raw:
      value: side_a_deployment_time_antenna_3
     side_a_deployment_time_antenna_4_raw:
      value: side_a_deployment_time_antenna_4
     side_b_ants_temperature_raw:
      value: side_b_ants_temperature
     side_b_ants_deployment_status_raw:
      value: side_b_ants_deployment_status
     side_b_ants_uptime_raw:
      value: side_b_ants_uptime
     side_b_deployment_count_antenna_1_raw:
      value: side_b_deployment_count_antenna_1
     side_b_deployment_count_antenna_2_raw:
      value: side_b_deployment_count_antenna_2
     side_b_deployment_count_antenna_3_raw:
      value: side_b_deployment_count_antenna_3
     side_b_deployment_count_antenna_4_raw:
      value: side_b_deployment_count_antenna_4
     side_b_deployment_time_antenna_1_raw:
      value: side_b_deployment_time_antenna_1
     side_b_deployment_time_antenna_2_raw:
      value: side_b_deployment_time_antenna_2
     side_b_deployment_time_antenna_3_raw:
      value: side_b_deployment_time_antenna_3
     side_b_deployment_time_antenna_4_raw:
      value: side_b_deployment_time_antenna_4 
################################################################################
#
#   Mainboard All Science
#
################################################################################      
  mainboard_all_science:
    seq:
      - id: mainboard_science_time
        type: u4
      - id: teach_wear_on
        type: u1
      - id: frequence_of_acquisitions
        type: u2
      - id: gain
        type: u4
      - id: number_of_acquisition_commanded
        type: u2
      - id: number_of_real_acquisition
        type: u2
      - id: hk_plus_5v
        type: u4
      - id: hk_minus_5v
        type: u4
      - id: hk_minus_5v_polar
        type: u4
      - id: hk_temp_adc
        type: u4
      - id: hk_fee_plus_x_vref
        type: u4
      - id: hk_fee_minus_x_vref
        type: u4
      - id: hk_fee_plus_y_vref
        type: u4
      - id: hk_fee_minus_y_vref
        type: u4
      - id: fee_plus_x_ers_1_signal
        type: u4
      - id: fee_plus_x_ers_1_temperature
        type: u4
      - id: fee_plus_x_ers_2_signal
        type: u4
      - id: fee_plus_x_ers_2_temperature
        type: u4
      - id: fee_plus_x_ers_3_signal
        type: u4
      - id: fee_plus_x_ers_3_temperature
        type: u4
      - id: fee_plus_x_uvs_signal
        type: u4
      - id: fee_minus_x_ers_1_signal
        type: u4
      - id: fee_minus_x_ers_1_temperature
        type: u4
      - id: fee_minus_x_ers_2_signal
        type: u4
      - id: fee_minus_x_ers_2_temperature
        type: u4
      - id: fee_minus_x_ers_3_signal
        type: u4
      - id: fee_minus_x_ers_3_temperature
        type: u4
      - id: fee_minus_x_uvs_signal
        type: u4
      - id: fee_plus_y_ers_1_signal
        type: u4
      - id: fee_plus_y_ers_1_temperature
        type: u4
      - id: fee_plus_y_ers_2_signal
        type: u4
      - id: fee_plus_y_ers_2_temperature
        type: u4
      - id: fee_plus_y_ers_3_signal
        type: u4
      - id: fee_plus_y_ers_3_temperature
        type: u4
      - id: fee_plus_y_uvs_signal
        type: u4
      - id: fee_minus_y_ers_1_signal
        type: u4
      - id: fee_minus_y_ers_1_temperature
        type: u4
      - id: fee_minus_y_ers_2_signal
        type: u4
      - id: fee_minus_y_ers_2_temperature
        type: u4
      - id: fee_minus_y_ers_3_signal
        type: u4
      - id: fee_minus_y_ers_3_temperature
        type: u4
      - id: fee_minus_y_uvs_signal
        type: u4
      - id: teachwear_acc_x
        type: u2
      - id: teachwear_acc_y
        type: u2
      - id: teachwear_acc_z
        type: u2
      - id: teachwear_deg_c
        type: u2
      - id: teachwear_gyro_x
        type: u2
      - id: teachwear_gyro_y
        type: u2
      - id: teachwear_gyro_z
        type: u2
      - id: teachwear_magn_x
        type: u2
      - id: teachwear_magn_y
        type: u2
      - id: teachwear_magn_z
        type: u2
      - id: teachwear_state
        type: u1
      - id: teachwear_reset_reason
        type: u1
      - id: teachwear_crc
        type: u2  
      - id: nb_tm_since_first_start
        type: u4
    instances:
     mainboard_science_time_raw:
      value: mainboard_science_time
     teach_wear_on_raw:
      value: teach_wear_on
     frequence_of_acquisitions_raw:
      value: frequence_of_acquisitions
     gain_raw:
      value: gain
     number_of_acquisition_commanded_raw:
      value: number_of_acquisition_commanded
     number_of_real_acquisition_raw:
      value: number_of_real_acquisition
     hk_plus_5v_raw:
      value: hk_plus_5v
     hk_minus_5v_raw:
      value: hk_minus_5v
     hk_minus_5v_polar_raw:
      value: hk_minus_5v_polar
     hk_temp_adc_raw:
      value: hk_temp_adc
     hk_fee_plus_x_vref_raw:
      value: hk_fee_plus_x_vref
     hk_fee_minus_x_vref_raw:
      value: hk_fee_minus_x_vref
     hk_fee_plus_y_vref_raw:
      value: hk_fee_plus_y_vref
     hk_fee_minus_y_vref_raw:
      value: hk_fee_minus_y_vref
     fee_plus_x_ers_1_signal_raw:
      value: fee_plus_x_ers_1_signal
     fee_plus_x_ers_1_temperature_raw:
      value: fee_plus_x_ers_1_temperature
     fee_plus_x_ers_2_signal_raw:
      value: fee_plus_x_ers_2_signal
     fee_plus_x_ers_2_temperature_raw:
      value: fee_plus_x_ers_2_temperature
     fee_plus_x_ers_3_signal_raw:
      value: fee_plus_x_ers_3_signal
     fee_plus_x_ers_3_temperature_raw:
      value: fee_plus_x_ers_3_temperature
     fee_plus_x_uvs_signal_raw:
      value: fee_plus_x_uvs_signal
     fee_minus_x_ers_1_signal_raw:
      value: fee_minus_x_ers_1_signal
     fee_minus_x_ers_1_temperature_raw:
      value: fee_minus_x_ers_1_temperature
     fee_minus_x_ers_2_signal_raw:
      value: fee_minus_x_ers_2_signal
     fee_minus_x_ers_2_temperature_raw:
      value: fee_minus_x_ers_2_temperature
     fee_minus_x_ers_3_signal_raw:
      value: fee_minus_x_ers_3_signal
     fee_minus_x_ers_3_temperature_raw:
      value: fee_minus_x_ers_3_temperature
     fee_minus_x_uvs_signal_raw:
      value: fee_minus_x_uvs_signal
     fee_plus_y_ers_1_signal_raw:
      value: fee_plus_y_ers_1_signal
     fee_plus_y_ers_1_temperature_raw:
      value: fee_plus_y_ers_1_temperature
     fee_plus_y_ers_2_signal_raw:
      value: fee_plus_y_ers_2_signal
     fee_plus_y_ers_2_temperature_raw:
      value: fee_plus_y_ers_2_temperature
     fee_plus_y_ers_3_signal_raw:
      value: fee_plus_y_ers_3_signal
     fee_plus_y_ers_3_temperature_raw:
      value: fee_plus_y_ers_3_temperature
     fee_plus_y_uvs_signal_raw:
      value: fee_plus_y_uvs_signal
     fee_minus_y_ers_1_signal_raw:
      value: fee_minus_y_ers_1_signal
     fee_minus_y_ers_1_temperature_raw:
      value: fee_minus_y_ers_1_temperature
     fee_minus_y_ers_2_signal_raw:
      value: fee_minus_y_ers_2_signal
     fee_minus_y_ers_2_temperature_raw:
      value: fee_minus_y_ers_2_temperature
     fee_minus_y_ers_3_signal_raw:
      value: fee_minus_y_ers_3_signal
     fee_minus_y_ers_3_temperature_raw:
      value: fee_minus_y_ers_3_temperature
     fee_minus_y_uvs_signal_raw:
      value: fee_minus_y_uvs_signal
     teachwear_acc_x_raw:
      value: teachwear_acc_x
     teachwear_acc_y_raw:
      value:  teachwear_acc_y
     teachwear_acc_z_raw:
      value: teachwear_acc_z
     teachwear_deg_c_raw:
      value: teachwear_deg_c
     teachwear_gyro_x_raw:
      value: teachwear_gyro_x
     teachwear_gyro_y_raw:
      value: teachwear_gyro_y
     teachwear_gyro_z_raw:
      value: teachwear_gyro_z
     teachwear_magn_x_raw:
      value: teachwear_magn_x
     teachwear_magn_y_raw:
      value: teachwear_magn_y
     teachwear_magn_z_raw:
      value: teachwear_magn_z
     teachwear_state_raw:
      value: teachwear_state
     teachwear_reset_reason_raw:
      value: teachwear_reset_reason
     teachwear_c_r_c_raw:
      value: teachwear_crc
     nb_tm_since_first_start_raw:
      value: nb_tm_since_first_start
################################################################################
#
#   AMSAT ASCII
#
################################################################################ 
  amsat_ascii:
    seq:
      - id: message
        type: str
        size-eos: true
        encoding: UTF-8
    instances:
     message_str:
      value: message
        
  mainboard_hk:
    seq:
      - id: mainboard_hk_time
        type: u4
      - id: hk_plus_5_v
        type: u2
      - id: hk_minus_5_v
        type: u2
      - id: hk_minus_polar
        type: u2
      - id: hk_temp_a_d_c
        type: u2
      - id: hk_fee_plus_x_vref
        type: u2
      - id: hk_fee_minus_x_vref
        type: u2
      - id: hk_fee_plus_y_vref
        type: u2
      - id: hk_fee_minus_y_vref
        type: u2
    instances:
     mainboard_h_k_time_raw:
      value: mainboard_hk_time
     hk_plus_5_v_raw:
      value: hk_plus_5_v
     hk_minus_5_v_raw:
      value: hk_minus_5_v
     hk_minus_polar_raw:
      value: hk_minus_polar
     hk_temp_a_d_c_raw:
      value: hk_temp_a_d_c
     hk_fee_plus_x_vref_raw:
      value: hk_fee_plus_x_vref
     hk_fee_minus_x_vref_raw:
      value: hk_fee_minus_x_vref
     hk_fee_plus_y_vref_raw:
      value: hk_fee_plus_y_vref
     hk_fee_minus_y_vref_raw:
      value: hk_fee_minus_y_vref
################################################################################
#
#   trxvurx HK
#
################################################################################       
  trxvurx_hk:
    seq:
      - id: trxvurx_instantaneous_received_signal_doppler_offset_at_the_receiver_port
        type: b12
      - id: trxvurx_instantaneous_received_signal_strength_at_the_receiver_port
        type: b12
      - id: trxvurx_supply_voltage
        type: b12
      - id: trxvurx_total_supply_current
        type: b12
      - id: trxvurx_transmitter_current
        type: b12
      - id: trxvurx_receiver_current
        type: b12
      - id: trxvurx_power_amplifier_current
        type: b12
      - id: trxvurx_power_amplifier_temperature
        type: b12
      - id: trxvurx_local_oscillator_temperature
        type: b12
      - id: trxvurx_zero_padding
        type: b4
      - id: trxvu_rx_uptime
        type: u4
# référence table 7.5.1 TRXVU interface control document
    instances:
        trxvurx_instantaneous_received_signal_doppler_hz:
          value: (trxvurx_instantaneous_received_signal_doppler_offset_at_the_receiver_port * 13.552) - 22300        
        trxvurx_instantaneous_received_signal_strength_dbm:
          value: trxvurx_instantaneous_received_signal_strength_at_the_receiver_port*0.03-152
        trxvurx_supply_voltage_v:
          value: trxvurx_supply_voltage*0.00488
        trxvurx_total_supply_current_ma:
          value: trxvurx_total_supply_current*0.16643964
        trxvurx_transmitter_current_ma:
          value: trxvurx_transmitter_current*0.16643964
        trxvurx_receiver_current_ma:
          value: trxvurx_receiver_current*0.16643964
        trxvurx_power_amplifier_current_ma:
          value: 1000.0 * trxvurx_power_amplifier_current*0.16643964
        trxvurx_power_amplifier_temperature_c:
          value: (trxvurx_power_amplifier_temperature)*-0.07669+195.6037
        trxvurx_local_oscillator_temperature_c:
          value: (trxvurx_local_oscillator_temperature)*-0.07669+195.6037
        trxvurx_zero_padding_raw:
          value: trxvurx_zero_padding
        trxvu_rx_uptime_raw:
          value: trxvu_rx_uptime        
################################################################################
#
#   OBC HK
#
################################################################################          
  obc_hk:
    seq:
      - id: dummy
        type: u1
      - id: spi_command_status
        type: u1
      - id: supervisor_enable_status
        type: u1
      - id: supervisor_uptime
        type: u4
      - id: iobc_uptime
        type: u4
      - id: iobc_reset_count
        type: u4
      - id: iobc_measure_temperature
        type: u2
      - id: iobc_measure_3v3_in
        type: u2
      - id: iobc_measure_3v3
        type: u2
      - id: iobc_measure_2v_reference
        type: u2
      - id: iobc_measure_1v8
        type: u2
      - id: iobc_measure_1v0
        type: u2
      - id: iobc_measure_current_3v3
        type: u2
      - id: iobc_measure_current_1v8
        type: u2
      - id: iobc_measure_current_1v0
        type: u2
      - id: iobc_measure_volt_rtc
        type: u2
      - id: iobc_adc_update_flag
        type: u1
      - id: iobc_crc8
        type: u1
      - id: photodiode_1
        type: u2
      - id: photodiode_2
        type: u2
      - id: photodiode_3
        type: u2
      - id: photodiode_4
        type: u2
      - id: photodiode_5
        type: u2
      - id: photodiode_6
        type: u2
      - id: panel_temperature_1
        type: s4
      - id: panel_temperature_2
        type: s4
      - id: panel_temperature_3
        type: s4
      - id: panel_temperature_4
        type: s4
      - id: panel_temperature_5
        type: s4
      - id: panel_temperature_6
        type: s4
    instances:
      dummy_raw:
        value: dummy
      spi_command_status_raw:
        value: spi_command_status
      supervisor_enable_status_raw:
        value: supervisor_enable_status
      supervisor_uptime_raw:
        value: supervisor_uptime
      iobc_uptime_raw:
        value: iobc_uptime
      iobc_reset_count_raw:
        value: iobc_reset_count
      iobc_measure_temperature_raw:
        value: iobc_measure_temperature
      iobc_measure_3v3_in_raw:
        value: iobc_measure_3v3_in
      iobc_measure_3v3_raw:
        value: iobc_measure_3v3
      iobc_measure_2v_reference_raw:
        value: iobc_measure_2v_reference
      iobc_measure_1v8_raw:
        value: iobc_measure_1v8
      iobc_measure_1v0_raw:
        value: iobc_measure_1v0
      iobc_measure_current_3v3_raw:
        value: iobc_measure_current_3v3
      iobc_measure_current_1v8_raw:
        value: iobc_measure_current_1v8
      iobc_measure_current_1v0_raw:
        value: iobc_measure_current_1v0
      iobc_measure_volt_rtc_raw:
        value: iobc_measure_volt_rtc
      iobc_adc_update_flag_raw:
        value: iobc_adc_update_flag
      iobc_crc8_raw:
        value: iobc_crc8
      photodiode1_raw:
        value: photodiode_1
      photodiode2_raw:
        value: photodiode_2
      photodiode3_raw:
        value: photodiode_3
      photodiode4_raw:
        value: photodiode_4
      photodiode5_raw:
        value: photodiode_5
      photodiode6_raw:
        value: photodiode_6
      panel_temperature_1_c:
        value:  panel_temperature_1 / 1024.0
      panel_temperature_2_c:
        value:  panel_temperature_2 / 1024.0
      panel_temperature_3_c:
        value:  panel_temperature_3 / 1024.0
      panel_temperature_4_c:
        value:  panel_temperature_4 / 1024.0
      panel_temperature_5_c:
        value:  panel_temperature_5 / 1024.0
      panel_temperature_6_c:
        value:  panel_temperature_6 / 1024.0
        

################################################################################
#
#   ieps HK status
#
################################################################################

  ieps_hk_status:
      seq:
      - id: h_k_stid 
        type: u1
      - id: h_k_ivid 
        type: u1
      - id: h_k_rc 
        type: u1
      - id: h_k_bid 
        type: u1
      - id: h_k_cmderr 
        type: b4
      - id: h_k_stat 
        type: b4
      - id: volt_brd_sup_raw
        type: u2
      - id: temp_raw
        type: u2
      - id: v_dist_input_raw
        type: u2
      - id: i_dist_input_raw
        type: u2
      - id: p_dist_input_raw
        type: u2
      - id: v_batt_input_raw
        type: u2
      - id: i_batt_input_raw
        type: u2
      - id: p_batt_input_raw
        type: u2
      - id: stat_obc_on
        type: u2
      - id: stat_obc_ocf
        type: u2
      - id: bat_stat
        type: u2
      - id: bat_temp_2_raw
        type: u2
      - id: volt_vd0
        type: u2
      - id: volt_vd1
        type: u2
      - id: volt_vd2
        type: u2
      - id: v_obc_00
        type: u2
      - id: i_obc_00
        type:  u2
      - id: p_obc_00
        type:  u2
      - id: v_obc_01
        type: u2
      - id: i_obc_01
        type:  u2
      - id: p_obc_01
        type:  u2
      - id: v_obc_02
        type: u2
      - id: i_obc_02
        type:  u2
      - id: p_obc_02
        type:  u2
      - id: v_obc_03
        type: u2
      - id: i_obc_03
        type:  u2
      - id: p_obc_03
        type:  u2
      - id: v_obc_05
        type: u2
      - id: i_obc_05
        type:  u2
      - id: p_obc_05
        type:  u2
      - id: v_obc_06
        type: u2
      - id: i_obc_06
        type:  u2
      - id: p_obc_06
        type:  u2
      - id: cc1
        size: 8
      - id: cc2
        size: 8
      - id: cc3
        size: 8
      - id: status_stid 
        type: u1
      - id: status_ivid 
        type: u1
      - id: status_rc 
        type: u1
      - id: status_bid 
        type: u1
      - id: status_cmderr 
        type: b4
      - id: status_stat 
        type: b4
      - id: mode
        type: u1
      - id: conf
        type: u1
      - id: reset_cause
        type: u1
      - id: uptime
        type: u4
      - id: error
        type: u2
      - id: rc_cnt_pwron
        type: u2
      - id: rc_cnt_wdg
        type: u2
      - id: rc_cnt_cmd
        type: u2
      - id: rc_cnt_mcu
        type: u2
      - id: rc_cnt_emlopo
        type: u2
      - id: prevcmd_elapsed
        type: u2
      instances:
        h_k_stid_raw: 
         value: h_k_stid
        h_k_ivid_raw:  
         value: h_k_ivid
        h_k_rc_raw:  
         value: h_k_rc
        h_k_bid_raw:  
         value: h_k_bid
        h_k_cmderr_raw:  
         value: h_k_cmderr
        h_k_stat_raw:  
         value: h_k_stat
        volt_brd_sup_raw_v: 
         value: volt_brd_sup_raw * 1000.0 / 819.0
        # ?? To be check - not coherent 
        temp_raw_t: 
         value: ((temp_raw -1168)*220.0/9.0 )/ 100.0
        v_dist_input_raw_v: 
         value: (v_dist_input_raw * 125.0/128.0)/ 1000.0
        i_dist_input_raw_ma: 
         value: i_dist_input_raw * 3125.0/10240.0 
        p_dist_input_raw_mw: 
         value: p_dist_input_raw *3125.0 / 3200.0
        v_batt_input_raw_v: 
         value: (v_batt_input_raw * 125.0/128.0)/ 1000.0
        i_batt_input_raw_ma: 
         value: 1000.0 * (i_batt_input_raw * 3125.0/10240.0)
        p_batt_input_raw_mw:
         value: p_batt_input_raw *3125.0 / 3200.0
        stat_obc_on_raw: 
         value: stat_obc_on
        stat_obc_ocf_raw: 
         value: stat_obc_ocf
        bat_stat_raw: 
         value: bat_stat
        bat_temp_2_raw_t: 
         value: bat_temp_2_raw * -0.047715407918 +98.38261483
        volt_vd0_raw:
          value: volt_vd0
        volt_vd1_raw:
          value: volt_vd1
        volt_vd2_raw: 
          value: volt_vd2
        v_obc_00_v:
         value: (v_obc_00  *125.0/128.0)/ 1000.0
        i_obc_00_ma:
         value: i_obc_00 *3125.0/20480.0
        p_obc_00_mw:
         value: p_obc_00 *3125.0 / 6400.0
        v_obc_01_v:
         value: ( v_obc_01  *125.0/128.0)/ 1000.0
        i_obc_01_ma:
         value: i_obc_01 *3125.0/20480.0
        p_obc_01_mw:
         value: p_obc_01 *3125.0 / 6400.0
        v_obc_02_v:
         value: (v_obc_02  *125.0/128.0)/ 1000.0
        i_obc_02_ma:
         value: i_obc_02 *3125.0/20480.0
        p_obc_02_mw:
         value: p_obc_02 *3125.0 / 6400.0   
        v_obc_03_v:
         value: (v_obc_03  *125.0/128.0)/ 1000.0
        i_obc_03_ma:
         value: i_obc_03 *3125.0/20480.0
        p_obc_03_mw:
         value: p_obc_03 *3125.0 / 6400.0
        v_obc_05_v:
         value: (v_obc_05  *125.0/128.0)/ 1000.0
        i_obc_05_ma:
         value: i_obc_05 *3125.0/20480.0
        p_obc_05_mw:
         value: p_obc_05 *3125.0 / 6400.0
        v_obc_06_v:
         value: (v_obc_06  *125.0/128.0)/ 1000.0
        i_obc_06_ma:
         value: i_obc_06 *3125.0/20480.0
        p_obc_06_mw :
         value: p_obc_06 *3125.0 / 6400.0
        cc1_byte:
         value: cc1
        cc2_byte:
         value: cc2
        cc3_byte:
         value: cc3
        status_stid_raw: 
         value: status_stid
        status_ivid_raw:
         value: status_ivid
        status_rc_raw:
         value: status_rc
        status_bid_raw: 
         value: status_bid
        status_cmderr_raw: 
         value: status_cmderr
        status_stat_raw: 
         value: status_stat
        mode_raw:
         value: mode
        conf_raw:
         value: conf
        reset_cause_raw:
         value: reset_cause
        uptime_raw:
         value: uptime
        error_raw:
         value: error
        rc_cnt_pwron_raw:
         value: rc_cnt_pwron
        rc_cnt_wdg_raw:
         value: rc_cnt_wdg
        rc_cnt_cmd_raw:
         value: rc_cnt_cmd
        rc_cnt_mcu_raw:
         value: rc_cnt_mcu
        rc_cnt_emlopo_raw:
         value: rc_cnt_emlopo
        prevcmd_elapsed_raw:
         value: prevcmd_elapsed
################################################################################
#
#   OBC Status
#
################################################################################
  obc_status:
    seq:
      - id: dummy
        type: u1
      - id: spi_command_status
        type: u1
      - id: supervisor_index_of_subsystem
        type: u1
      - id: supervisor_major_version
        type: u1
      - id: supervisor_minor_version
        type: u1
      - id: supervisor_patch_version
        type: u1
      - id: supervisor_git_head_version
        type: u4
      - id: supervisor_serial_number
        type: u2
      - id: compilation_information
        size: 19
      - id: clock_speed
        type: u1
      - id: code_type
        type: u1
      - id: crc_8
        type: u1
      - id: sw_mmode
        type: u1
      - id: last_reset_reason
        type: u1
      - id: reserved 
        type: u1
      - id: nb_reset
        type: u1
      - id: reserved2 
        type: u1
      - id: deploy_antennas_system
        type: u1
      - id: nb_tm_since_first_start
        type: u4
      - id: nb_tc_since_first_start
        type: u4
      - id: nb_bad_tc_since_first_start
        type: u4
      - id: nb_tm_in_sdcard
        type: u4
      - id: sdcard_status
        type: u1
      - id: sdcard_last_error
        type: u4
      - id: old_time_t_m_in_sdcard
        type: b56
      - id: new_time_t_m_in_sdcard
        type: b56
    instances:
      dummydummy:
       value: dummy
      spi_command_status_raw:
       value: spi_command_status
      supervisor_index_of_subsystem_raw:
       value: supervisor_index_of_subsystem
      supervisor_major_version_raw:
       value: supervisor_major_version
      supervisor_minor_version_raw:
       value: supervisor_minor_version
      supervisor_patch_version_raw:
       value: supervisor_patch_version
      supervisor_git_head_version_raw:
       value: supervisor_git_head_version
      supervisor_serial_number_raw:
       value: supervisor_serial_number
      compilation_information_byte:
       value: compilation_information
      clock_speed_raw:
       value: clock_speed
      code_type_raw:
       value: code_type
      crc_8_raw:
       value: crc_8
      sw_mmode_raw:
       value: sw_mmode
      last_reset_reason_raw:
       value: last_reset_reason
      reserved_raw:
       value: reserved
      nb_reset_raw:
       value: nb_reset
      reserved2_raw: 
       value: reserved2
      deploy_antennas_system_raw:
       value: deploy_antennas_system
      nb_tm_since_first_start_raw:
       value: nb_tm_since_first_start
      nb_tc_since_first_start_raw:
       value: nb_tc_since_first_start
      nb_bad_tc_since_first_start_raw:
       value: nb_bad_tc_since_first_start
      nb_tm_in_sdcard_raw:
       value: nb_tm_in_sdcard
      sdcard_status_raw:
       value: sdcard_status
      sdcard_last_error_raw:
       value: sdcard_last_error
      old_time_t_m_in_sdcard_raw:
       value: old_time_t_m_in_sdcard
      new_time_t_m_in_sdcard_raw:
       value: new_time_t_m_in_sdcard    
################################################################################
#
#   trxvutx HK
#
################################################################################    
    
  trxvutx_hk:
    seq:
      - id: trxvutx_instantaneous_rf_reflected_power_from_transmitter_port
        type : b12
      - id: trxvutx_instantaneous_rf_forward_power_from_transmitter_port
        type : b12
      - id: trxvutx_supply_voltage
        type : b12
      - id: trxvutx_total_supply_current
        type : b12
      - id: trxvutx_transmitter_current
        type : b12
      - id: trxvutx_receiver_current
        type : b12
      - id: trxvutx_power_amplifier_current
        type : b12
      - id: trxvutx_power_amplifier_temperature
        type : b12 
      - id: trxvutx_local_oscillator_temperature
        type : b12
      - id: trxvutx_zero_padding
        type: b4 
      - id: trxvu_tx_uptime
        type: u4
      - id: trxvu_tx_state
        type: u1 
    instances:
        trxvutx_instantaneous_rf_reflected_power_from_transmitter_port_mw:
          value: 1000.0 * trxvutx_instantaneous_rf_reflected_power_from_transmitter_port * trxvutx_instantaneous_rf_reflected_power_from_transmitter_port * 5.887 * 0.00001
        trxvutx_instantaneous_rf_forward_power_from_transmitter_port_mw:
          value: 1000.0 * trxvutx_instantaneous_rf_forward_power_from_transmitter_port * trxvutx_instantaneous_rf_forward_power_from_transmitter_port * 5.887 * 0.00001
        trxvutx_supply_voltage_v:
          value: 0.00488 * trxvutx_supply_voltage   
        trxvutx_total_supply_current_ma: 
          value: 0.16643964 * trxvutx_total_supply_current 
        trxvutx_transmitter_current_ma:
          value: trxvutx_transmitter_current * 0.16643964
        trxvutx_receiver_current_ma:
          value: trxvutx_receiver_current * 0.16643964
        trxvutx_power_amplifier_current_ma:
          value: 1000.0 * trxvutx_power_amplifier_current * 0.16643964
        trxvutx_power_amplifier_temperature_c:
          value: trxvutx_power_amplifier_temperature * -0.07669 + 195.6037
        trxvutx_local_oscillator_temperature_c:
          value: trxvutx_local_oscillator_temperature *  -0.07669 + 195.6037
        trxvutx_zero_padding_raw:
          value: trxvutx_zero_padding
        trxvu_tx_uptime_raw:
          value: trxvu_tx_uptime
        trxvu_tx_state_raw:
          value: trxvu_tx_state
        
################################################################################
#
#   imtq  HK
#
################################################################################        
        
  imtq_hk:
    seq:
      - id: digitale_voltage
        type: u2  
      - id: analog_voltage
        type: u2   
      - id: digital_current
        type: u2  
      - id: analog_current
        type: u2  
      - id: measure_coil_x_current
        type: u2  
      - id: measure_coil_y_current
        type: u2  
      - id: measure_coil_z_current
        type: u2  
      - id: measure_coil_x_temperature
        type: u2  
      - id: measure_coil_y_temperature
        type: u2  
      - id: measure_coil_z_temperature
        type: u2  
      - id: mcu_temperature
        type: u2  
      - id: imtq_system_state_mode
        type: u1 
      - id: imtq_system_state_error
        type: u1  
      - id: imtq_system_state_configuration
        type: u1
      - id: imtq_system_state_uptime
        type: u4
    instances:
        digitale_voltage_v:
          value: 2 *  (2.5/4095) * digitale_voltage   
        analog_voltage_v: 
          value: 2 *  (2.5/4095) * analog_voltage
        digital_current_raw:
          value: digital_current  
        analog_current_raw:
          value: analog_current 
        measure_coil_x_current_ma:
          value:  1000.0 * (( (2.5/4095) * measure_coil_x_current) -1.03)/2.0
        measure_coil_y_current_ma:
          value:   1000.0 * (( (2.5/4095) * measure_coil_y_current) -1.03)/2.0
        measure_coil_z_current_ma:
          value:  1000.0 *  (( (2.5/4095) * measure_coil_z_current) -1.03)/0.48   
        measure_coil_x_temperature_c:
          value: (( (2.5/4095) * measure_coil_x_temperature) -1.567) * -1.0 /0.0081
        measure_coil_y_temperature_c:
          value: (( (2.5/4095) * measure_coil_y_temperature) -1.567) * -1.0 /0.0081 
        measure_coil_z_temperature_c:
          value: (( (2.5/4095) * measure_coil_z_temperature) -1.567) * -1.0 /0.0081        
        mcu_temperature_c:
          value:  (( (2.5/4095) * mcu_temperature) -0.680) * - 1.0 / 0.00225
        imtq_system_state_mode_raw:
          value: imtq_system_state_mode 
        imtq_system_state_error_raw:
          value: imtq_system_state_error  
        imtq_system_state_configuration_raw:
          value: imtq_system_state_configuration
        imtq_system_state_uptime_raw:
          value: imtq_system_state_uptime          
          
################################################################################
#
#   beacon
#
################################################################################           
          
  beacon:
    seq:
      - id: sw_mode
        type: u1
      - id: last_reset_reason
        type: u1
      - id: reset_order
        type: u1
      - id: nb_reset
        type: u1
      - id: format_sdcard_order
        type: u1
      - id: deploy_antennas_system
        type: u1
      - id: nb_tm_since_first_start
        type: u4
      - id: nb_tc_since_first_start
        type: u4
      - id: nb_tc_ping_since_first_start
        type: u4
      - id: nb_bad_tc_since_first_start
        type: u4
      - id: nb_tm_in_sdcard
        type: u4
      - id: trxvutx_instantaneous_rf_reflected_power_from_transmitter_port
        type: b12
      - id: trxvutx_instantaneous_rf_forward_power_from_transmitter_port
        type: b12
      - id: trxvutx_supply_voltage
        type: b12
      - id: trxvutx_total_supply_current
        type: b12
      - id: trxvutx_transmitter_current
        type: b12
      - id: trxvutx_receiver_current
        type: b12
      - id: trxvutx_power_amplifier_current
        type: b12
      - id: trxvutx_power_amplifier_temperature
        type: b12
      - id: trxvutx_local_oscillator_temperature
        type: b12
      - id: trxvurx_instantaneous_received_signal_doppler_offset_at_the_receiver_port
        type: b12
      - id: trxvurx_instantaneous_received_signal_strength_at_the_receiver_port
        type: b12
      - id: trxvurx_supply_voltage
        type: b12
      - id: trxvurx_total_supply_current
        type: b12
      - id: trxvurx_transmitter_current
        type: b12
      - id: trxvurx_receiver_current
        type: b12
      - id: trxvurx_power_amplifier_current
        type: b12
      - id: trxvurx_power_amplifier_temperature
        type: b12
      - id: trxvurx_local_oscillator_temperature
        type: b12
      - id: imtq_system_state_mode
        type: u1
      - id: measure_coil_x_current
        type: u2
      - id: measure_coil_y_current
        type: u2
      - id: measure_coil_z_current
        type: u2
      - id: measure_coil_x_temperature
        type: u2
      - id: measure_coil_y_temperature
        type: u2
      - id: measure_coil_z_temperature
        type: u2
      - id: mcu_temperature
        type: u2
      - id: side_a_ants_temperature
        type: u2
      - id: side_a_ants_deployment_status
        type: u2
      - id: volt_brd_sup_raw
        type: u2
      - id: temp_raw
        type: u2
      - id: v_dist_input_raw
        type: u2
      - id: i_dist_input_raw
        type: u2
      - id: p_dist_input_raw
        type: u2
      - id: v_batt_input_raw
        type: u2
      - id: i_batt_input_raw
        type: u2
      - id: p_batt_input_raw
        type: u2
      - id: stat_obc_on
        type: u2
      - id: stat_obc_ocf
        type: u2
      - id: bat_stat
        type: u2
      - id: bat_temp_2_raw
        type: u2
      - id: volt_vd0
        type: u2
      - id: volt_vd1
        type: u2
      - id: volt_vd2
        type: u2
      - id: v_obc_00
        type: u2
      - id: i_obc_00
        type:  u2
      - id: p_obc_00
        type:  u2
      - id: v_obc_01
        type: u2
      - id: i_obc_01
        type:  u2
      - id: p_obc_01
        type:  u2
      - id: v_obc_02
        type: u2
      - id: i_obc_02
        type:  u2
      - id: p_obc_02
        type:  u2
      - id: v_obc_03
        type: u2
      - id: i_obc_03
        type:  u2
      - id: p_obc_03
        type:  u2
      - id: v_obc_05
        type: u2
      - id: i_obc_05
        type:  u2
      - id: p_obc_05
        type:  u2
      - id: v_obc_06
        type: u2
      - id: i_obc_06
        type:  u2
      - id: p_obc_06
        type:  u2
      - id: status_stid
        type: u1
      - id: status_ivid
        type: u1
      - id: status_rc
        type: u1
      - id: status_bid
        type: u1
      - id: status_cmderr
        type: b4
      - id: status_stat
        type: b4
      - id: mode
        type: u1
      - id: conf
        type: u1
      - id: reset_cause
        type: u1
      - id: uptime
        type: u4
      - id: error
        type: u2
      - id: rc_cnt_pwron
        type: u2
      - id: rc_cnt_wdg
        type: u2
      - id: rc_cnt_cmd
        type: u2
      - id: rc_cnt_mcu
        type: u2     
      - id: rc_cnt_emlopo
        type: u2
      - id: prevcmd_elapsed
        type: u2      
      - id: photodiode_1
        type: u2
      - id: photodiode_2
        type: u2
      - id: photodiode_3
        type: u2
      - id: photodiode_4
        type: u2
      - id: photodiode_5
        type: u2
      - id: photodiode_6
        type: u2
      - id: panel_temperature_1
        type: s4
      - id: panel_temperature_2
        type: s4
      - id: panel_temperature_3
        type: s4
      - id: panel_temperature_4
        type: s4
      - id: panel_temperature_5
        type: s4
      - id: panel_temperature_6
        type: s4    

    instances: 

        sw_mode_raw:
          value:  sw_mode
          doc: |
           : mode value 
           MODE_INIT = 0 
           MODE_DETUMBLING = 1 
           MODE_STANDBY = 2 
           MODE_OPERATIONAL = 3 
           MODE_SAFE = 4 
           MODE_TRANSPONDER = 5
        last_reset_reason_raw:
          value:  last_reset_reason
          doc: |
           : last reset value
           First start = 0 
           TC Init received = 0x80 
           No TC since 4 days = 0x81 
           Unknown reason = 0x81
        reset_order_raw:
          value:  reset_order
          doc: |
           Order by TC = 0xCA
           No order = 0
        nb_reset_raw:
          value:  nb_reset
        format_sdcard_order_raw:
          value:  format_sdcard_order
          doc: |
           Order to Format SdCard 0 = 0
           Order to Format SdCard 1 = 1
           Order to NOT Format SdCard 0 = 0xAC
           Order to NOT Format SdCard 1 = 0xAD

        deploy_antennas_system_raw:
          value:  deploy_antennas_system
          doc : |
           : value 
           Nominal = 0 
           No deploy = 0x11 
           Deployment Debug = 0xDB
        nb_tm_since_first_start_raw:
          value:  nb_tm_since_first_start
        nb_tc_since_first_start_raw:
          value:  nb_tc_since_first_start
        nb_tc_ping_since_first_start_raw:
          value:  nb_tc_ping_since_first_start
        nb_bad_tc_since_first_start_raw:
          value:  nb_bad_tc_since_first_start
        nb_tm_in_sdcard_raw:
          value:  nb_tm_in_sdcard
        trxvutx_instantaneous_rf_reflected_power_from_transmitter_port_mw:
          value: 1000.0 * trxvutx_instantaneous_rf_reflected_power_from_transmitter_port * trxvutx_instantaneous_rf_reflected_power_from_transmitter_port * 5.887 * 0.00001
        trxvutx_instantaneous_rf_forward_power_from_transmitter_port_mw:
          value: 1000.0 * trxvutx_instantaneous_rf_forward_power_from_transmitter_port * trxvutx_instantaneous_rf_forward_power_from_transmitter_port * 5.887 * 0.00001
        trxvutx_supply_voltage_v:
          value: 0.00488 * trxvutx_supply_voltage 
        trxvutx_total_supply_current_ma: 
          value: 0.16643964 * trxvutx_total_supply_current 
        trxvutx_transmitter_current_ma:
          value: trxvutx_transmitter_current * 0.16643964
        trxvutx_receiver_current_ma:
          value: trxvutx_receiver_current * 0.16643964
        trxvutx_power_amplifier_current_ma:
          value: 1000.0 * trxvutx_power_amplifier_current * 0.16643964
        trxvutx_power_amplifier_temperature_c:
          value: trxvutx_power_amplifier_temperature * -0.07669 + 195.6037
        trxvutx_local_oscillator_temperature_c:
          value: trxvutx_local_oscillator_temperature * -0.07669 + 195.6037
        trxvurx_instantaneous_received_signal_doppler_hz:
          value: (trxvurx_instantaneous_received_signal_doppler_offset_at_the_receiver_port * 13.552) - 22300        
        trxvurx_instantaneous_received_signal_strength_dbm:
          value: trxvurx_instantaneous_received_signal_strength_at_the_receiver_port*0.03-152
        trxvurx_supply_voltage_v:
          value: 0.00488 * trxvurx_supply_voltage   
        trxvurx_total_supply_current_ma: 
          value: 0.16643964 * trxvurx_total_supply_current
        trxvurx_transmitter_current_ma:
          value: trxvurx_transmitter_current * 0.16643964
        trxvurx_receiver_current_ma:
          value: trxvurx_receiver_current * 0.16643964
        trxvurx_power_amplifier_current_ma:
          value: 1000.0 *  trxvurx_power_amplifier_current *0.16643964
        trxvurx_power_amplifier_temperature_c:
          value: trxvurx_power_amplifier_temperature *-0.07669+195.6037
        trxvurx_local_oscillator_temperature_c:
          value: trxvurx_local_oscillator_temperature *-0.07669+195.6037
        imtq_system_state_mode_raw:
          value: imtq_system_state_mode
          doc:  |
           value :
           IDLE = 0 
           SELFTEST = 1 
           DETUMBLE = 2
        measure_coil_x_current_ma:
          value:  1000.0 * (( (2.5/4095) * measure_coil_x_current) -1.03)/2.0
        measure_coil_y_current_ma:
          value:  1000.0 *  (( (2.5/4095) * measure_coil_y_current) -1.03)/2.0
        measure_coil_z_current_ma:
          value:  1000.0 * (( (2.5/4095) * measure_coil_z_current) -1.03)/0.48   
        measure_coil_x_temperature_c:
          value: (( (2.5/4095) * measure_coil_x_temperature) -1.567) * -1.0 /0.0081
        measure_coil_y_temperature_c:
          value: (( (2.5/4095) * measure_coil_y_temperature) -1.567) * -1.0 /0.0081 
        measure_coil_z_temperature_c:
          value: (( (2.5/4095) * measure_coil_z_temperature) -1.567) * -1.0 /0.0081        
        mcu_temperature_c:
          value:  (( (2.5/4095) * mcu_temperature) -0.680) * - 1.0 /0.00225
        side_a_ants_temperature_raw:
          value: side_a_ants_temperature
        side_a_ants_deployment_status_raw:
          value: side_a_ants_deployment_status
        volt_brd_sup_raw_v: 
         value: volt_brd_sup_raw * 1000.0 / 819.0
        # ?? To be check - not coherent 
        temp_raw_t: 
         value: ((temp_raw -1168)*220.0/9.0 )/ 100.0
        v_dist_input_raw_v: 
         value: (v_dist_input_raw * 125.0/128.0)/ 1000.0
        i_dist_input_raw_ma: 
         value: i_dist_input_raw * 3125.0/10240.0 
        p_dist_input_raw_mw: 
         value: p_dist_input_raw *3125.0 / 3200.0
        v_batt_input_raw_v: 
         value: (v_batt_input_raw * 125.0/128.0)/ 1000.0
        i_batt_input_raw_ma: 
         value: 1000.0 * ( i_batt_input_raw * 3125.0/10240.0 )
        p_batt_input_raw_mw:
         value: p_batt_input_raw *3125.0 / 3200.0
        stat_obc_on_raw:
          value: stat_obc_on
          doc: |
             bit n = 1 indicates the channel n is ON 9 firsts bits used
        stat_obc_ocf_raw:
          value: stat_obc_ocf
          doc: |
              bit n = 1 indicates a overcurrent on the channel n 9 firsts bits used
        bat_stat_raw:
          value: bat_stat
        bat_temp_2_raw_t: 
         value: bat_temp_2_raw * -0.047715407918 +98.38261483
        volt_vd0_raw:
          value: volt_vd0
        volt_vd1_raw:
          value: volt_vd1
        volt_vd2_raw: 
          value: volt_vd2
        v_obc_00_v:
         value: (v_obc_00  *125.0/128.0)/ 1000.0
        i_obc_00_ma:
         value: i_obc_00 *3125.0/20480.0
        p_obc_00_mw:
         value: p_obc_00 *3125.0 / 6400.0
        v_obc_01_v:
         value: ( v_obc_01  *125.0/128.0)/ 1000.0
        i_obc_01_ma:
         value: i_obc_01 *3125.0/20480.0
        p_obc_01_mw:
         value: p_obc_01 *3125.0 / 6400.0
        v_obc_02_v:
         value: (v_obc_02  *125.0/128.0)/ 1000.0
        i_obc_02_ma:
         value: i_obc_02 *3125.0/20480.0
        p_obc_02_mw:
         value: p_obc_02 *3125.0 / 6400.0   
        v_obc_03_v:
         value: (v_obc_03  *125.0/128.0)/ 1000.0
        i_obc_03_ma:
         value: i_obc_03 *3125.0/20480.0
        p_obc_03_mw:
         value: p_obc_03 *3125.0 / 6400.0
        v_obc_05_v:
         value: (v_obc_05  *125.0/128.0)/ 1000.0
        i_obc_05_ma:
         value: i_obc_05 *3125.0/20480.0
        p_obc_05_mw:
         value: p_obc_05 *3125.0 / 6400.0
        v_obc_06_v:
         value: (v_obc_06  *125.0/128.0)/ 1000.0
        i_obc_06_ma:
         value: i_obc_06 *3125.0/20480.0
        p_obc_06_mw :
         value: p_obc_06 *3125.0 / 6400.0
        status_stid_raw:
          value: status_stid
        status_ivid_raw:
          value: status_ivid
        status_rc_raw:
          value: status_rc
        status_bid_raw:
          value: status_bid
        status_cmderr_raw:
          value: status_cmderr
        status_stat_raw:
          value: status_stat
        mode_raw:
          value: mode
          doc: |
           value :
           0 = Startup 
           1 = Nominal 
           2 = Safety 
           3 = Emergency low power 8
          
        conf_raw:
          value: conf
          doc: |
           value : 
           0 = Parameters have not been altered since the last load/save.
           1 = Parameters have been altered since the last load/save.
        reset_cause_raw:
          value: reset_cause
          doc: |
           value : 
           0 = Power-on; system returned from an unpowered state (e.g. power cycle). 
           1 = Watchdog; system was reset due to watchdog timeout, caused by a too-long delay between command interactions with the parent system. 
           2 = Commanded; system was reset after having received a reset command. 
           3 = Control system reset; an upset in the EPS control system caused a reset. 
           4 = Emlopo; emergency low power mode was engaged because the input voltage dropped below the threshold.
        uptime_raw:
          value: uptime
        error_raw:
          value: error
        rc_cnt_pwron_raw:
          value: rc_cnt_pwron
        rc_cnt_wdg_raw:
          value: rc_cnt_wdg
        rc_cnt_cmd_raw:
          value: rc_cnt_cmd
        rc_cnt_mcu_raw:
          value: rc_cnt_mcu
        rc_cnt_emlopo_raw:
          value: rc_cnt_emlopo
        prevcmd_elapsed_raw:
          value: prevcmd_elapsed
        photodiode_1_raw:
          value: photodiode_1
        photodiode_2_raw:
          value: photodiode_2
        photodiode_3_raw:
          value: photodiode_3
        photodiode_4_raw:
          value: photodiode_4
        photodiode_5_raw:
          value: photodiode_5
        photodiode_6_raw:
          value: photodiode_6
        panel_temperature_1_c:
          value:  panel_temperature_1 / 1024.0
        panel_temperature_2_c:
          value:  panel_temperature_2 / 1024.0
        panel_temperature_3_c:
          value:  panel_temperature_3 / 1024.0
        panel_temperature_4_c:
          value:  panel_temperature_4 / 1024.0
        panel_temperature_5_c:
          value:  panel_temperature_5 / 1024.0
        panel_temperature_6_c:
          value:  panel_temperature_6 / 1024.0

